@@ -7,12 +7,12 @@ import fmpy.cross_check
 print("import: 'fmpy.examples'")
 import fmpy.examples
 
+print("import: 'fmpy.fmucontainer'")
+import fmpy.fmucontainer
+
 print("import: 'fmpy.ssp'")
 import fmpy.ssp
 
-print("import: 'fmpy.ssp.examples'")
-import fmpy.ssp.examples
-
 print("import: 'fmpy.sundials'")
 import fmpy.sundials
 
